geowatch.utils.lightning\_ext.util\_device module
=================================================

.. automodule:: geowatch.utils.lightning_ext.util_device
   :members:
   :undoc-members:
   :show-inheritance:
